package com.qianhe.service;

import java.util.List;
import com.qianhe.domain.WdWdxxRd;

/**
 * 文档-热点信息Service接口
 * 
 * @author qianhe
 * @date 2024-09-14
 */
public interface IWdWdxxRdService 
{
    /**
     * 查询文档-热点信息
     * 
     * @param id 文档-热点信息主键
     * @return 文档-热点信息
     */
    public WdWdxxRd selectWdWdxxRdById(Long id);

    /**
     * 查询文档-热点信息列表
     * 
     * @param wdWdxxRd 文档-热点信息
     * @return 文档-热点信息集合
     */
    public List<WdWdxxRd> selectWdWdxxRdList(WdWdxxRd wdWdxxRd);

    /**
     * 新增文档-热点信息
     * 
     * @param wdWdxxRd 文档-热点信息
     * @return 结果
     */
    public int insertWdWdxxRd(WdWdxxRd wdWdxxRd);

    /**
     * 修改文档-热点信息
     * 
     * @param wdWdxxRd 文档-热点信息
     * @return 结果
     */
    public int updateWdWdxxRd(WdWdxxRd wdWdxxRd);

    /**
     * 批量删除文档-热点信息
     * 
     * @param ids 需要删除的文档-热点信息主键集合
     * @return 结果
     */
    public int deleteWdWdxxRdByIds(Long[] ids);

    /**
     * 删除文档-热点信息信息
     * 
     * @param id 文档-热点信息主键
     * @return 结果
     */
    public int deleteWdWdxxRdById(Long id);
}
